sample_test_fail_all_setup_20141211_225908

zopkio

- Summary
- Results
  - sample_config2
    - test1
    - test0
    - test2
  - sample_config1
    - test1
    - test0
    - test2
- Diff
- Logs

### Test Summary

Total tests | Total passed | Total failed | Total skipped | Total execution time
--- | --- | --- | --- | ---
6 | 0 | 0 | 6 | 0.13064789772 sec

###

Configuration name | Skipped? | Has failures? | Has skipped?
--- | --- | --- | ---
sample_config2 | No | No | Yes
sample_config1 | No | No | Yes